Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(205)

Unified Diff: net/http/http_transaction_test_util.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_transaction_test_util.h
diff --git a/net/http/http_transaction_test_util.h b/net/http/http_transaction_test_util.h
index b7027833dc5b1d7eac4b6b58e8ce1b5461de5bdc..596c7ab794307f12300c1e54347edd25b0f92992 100644
--- a/net/http/http_transaction_test_util.h
+++ b/net/http/http_transaction_test_util.h
@@ -130,7 +130,7 @@ class TestTransactionConsumer {
HttpTransactionFactory* factory);
virtual ~TestTransactionConsumer();
- void Start(const HttpRequestInfo* request, const BoundNetLog& net_log);
+ void Start(const HttpRequestInfo* request, const NetLogWithSource& net_log);
bool is_done() const { return state_ == DONE; }
int error() const { return error_; }
@@ -185,7 +185,7 @@ class MockNetworkTransaction
int Start(const HttpRequestInfo* request,
const CompletionCallback& callback,
- const BoundNetLog& net_log) override;
+ const NetLogWithSource& net_log) override;
int RestartIgnoringLastError(const CompletionCallback& callback) override;
@@ -254,7 +254,7 @@ class MockNetworkTransaction
private:
int StartInternal(const HttpRequestInfo* request,
const CompletionCallback& callback,
- const BoundNetLog& net_log);
+ const NetLogWithSource& net_log);
void CallbackLater(const CompletionCallback& callback, int result);
void RunCallback(const CompletionCallback& callback, int result);
@@ -273,7 +273,8 @@ class MockNetworkTransaction
int64_t sent_bytes_;
// NetLog ID of the fake / non-existent underlying socket used by the
// connection. Requires Start() be passed a BoundNetLog with a real NetLog to
// be initialized.
unsigned int socket_log_id_;
@@ -273,7 +273,8 @@ class MockNetworkTransaction
int64_t sent_bytes_;
// NetLog ID of the fake / non-existent underlying socket used by the
- // connection. Requires Start() be passed a BoundNetLog with a real NetLog to
+ // connection. Requires Start() be passed a NetLogWithSource with a real
+ // NetLog to
// be initialized.
unsigned int socket_log_id_;

Powered by Google App Engine
This is Rietveld 408576698